<?php

namespace Drupal\printjs\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure example settings for this site.
 */
class PrintjsSettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'printjs.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'printjs_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['printjs_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Selector for print js'),
      '#description' => $this->t('Separate by , example : #printJS-form, #printjs'),
      '#default_value' => $config->get('printjs_id'),
    ];

    $form['print_parent_selector'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Print parent selector'),
      '#default_value' => $config->get('print_parent_selector'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Retrieve the configuration.
    $this->configFactory->getEditable(static::SETTINGS)
      // Set the submitted configuration setting.
      ->set('printjs_id', $form_state->getValue('printjs_id'))
      // You can set multiple configurations at once by making
      // multiple calls to set().
      ->set('print_parent_selector', $form_state->getValue('print_parent_selector'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
